#[non_exhaustive]pub enum LinuxCapability {
Show 23 variants
Chown,
DacOverride,
DacReadSearch,
FOwner,
FSetId,
Kill,
SetGid,
SetUid,
SetPCap,
NetBindService,
NetRaw,
NetAdmin,
SysChroot,
SysPtrace,
SysAdmin,
SysBoot,
SysNice,
SysResource,
SysTime,
MkNod,
AuditWrite,
AuditControl,
SetFCap,
}Expand description
Linux process capability.
Covers the most commonly used capabilities.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Chown
CAP_CHOWN: Make arbitrary changes to file UIDs and GIDs
DacOverride
CAP_DAC_OVERRIDE: Bypass file read, write, and execute permission checks
DacReadSearch
CAP_DAC_READ_SEARCH: Bypass file read permission checks and directory read/execute checks
FOwner
CAP_FOWNER: Bypass permission checks on operations that normally require the filesystem UID
FSetId
CAP_FSETID: Don’t clear set-user-ID and set-group-ID mode bits
Kill
CAP_KILL: Bypass permission checks for sending signals
SetGid
CAP_SETGID: Make arbitrary manipulations of process GIDs and supplementary GID list
SetUid
CAP_SETUID: Make arbitrary manipulations of process UIDs
SetPCap
CAP_SETPCAP: Modify process capabilities
NetBindService
CAP_NET_BIND_SERVICE: Bind a socket to privileged ports (port numbers less than 1024)
NetRaw
CAP_NET_RAW: Use RAW and PACKET sockets; bind to any address for transparent proxying
NetAdmin
CAP_NET_ADMIN: Perform various network-related operations
SysChroot
CAP_SYS_CHROOT: Use chroot()
SysPtrace
CAP_SYS_PTRACE: Trace arbitrary processes using ptrace()
SysAdmin
CAP_SYS_ADMIN: Perform a range of system administration operations
SysBoot
CAP_SYS_BOOT: Use reboot() and kexec_load()
SysNice
CAP_SYS_NICE: Raise process nice value and change the nice value for arbitrary processes
SysResource
CAP_SYS_RESOURCE: Override resource limits
SysTime
CAP_SYS_TIME: Set system clock; set real-time (hardware) clock
MkNod
CAP_MKNOD: Create special files using mknod()
AuditWrite
CAP_AUDIT_WRITE: Write records to kernel auditing log
AuditControl
CAP_AUDIT_CONTROL: Enable and disable kernel auditing
SetFCap
CAP_SETFCAP: Set file capabilities
Implementations